@@ -6,7 +6,7 @@ from .exceptions import GraphQLJWTError
 from .utils import get_authorization_header
 
 
-class JWTMiddleware(object):
+class JSONWebTokenMiddleware(object):
 
     def __init__(self, get_response):
         self.get_response = get_response
